
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.21.5',
    'branch_nick': 'patch-0-Release__1_21_5_preparation',
    'revision_id': '0ac16e69b21b8dae9195d6a52b3d04549ff1e471',
    'revno': 9088
}
